<?php
/**
 * Admin Form - Simple Editing
 *
 */
function om_tools_admin() {
  drupal_set_title(t('OM Tools 2 Settings'));
  // OM Tools container
  $om_tools = variable_get('om_tools', '');     
  $tools    = om_tools_get();
  $form     = array();
  $reset    = 0;  
  foreach ($tools as $key => $module) {
    om_tools_settings($form, $module);
    if (isset($om_tools[$module])) {
      foreach ($om_tools[$module] as $omkey => $omval) {
        $om_tool_name = array_reverse(explode('_', $omkey));
        if ($om_tool_name[0] == 'reset') $reset += $omval;
      }  
    }  
  }

  // button save again will show if the variable is empty    
  if ($reset) $form['save again'] = array( '#type' => 'submit', '#value' => t('Save Settings Again'), );
  // button initialize will show if the variable is empty    
  if (empty($om_tools)) $form['initialize'] = array( '#type' => 'submit', '#value' => t('Initialize Settings'), );
  // button save will show if the variable is not empty      
  if (!empty($om_tools) && !$reset) $form['save'] = array( '#type' => 'submit', '#value' => t('Save Settings'), );
  
  return $form;
}


/**
 * OM Tools requires tools dynamically
 *
 */
function om_tools_settings(&$form, $module = NULL) {
  $om_tools_values = variable_get('om_tools', '');
  //dsm($om_tools_values);  
  $default_values = isset($om_tools_values[$module]) ? $om_tools_values[$module]: '';

  if (module_exists($module)) {
    include_once(drupal_get_path('module', 'om_tools') . '/tools/' . $module . '/' . $module . '.inc');
    $function = 'om_' . $module . '_tools';
    if (function_exists($function)) {
      return $function($form, $default_values);  
    }
  }
}   


/**
 * 1 Submit for all settings
 *
 */
function om_tools_admin_submit($form, $form_state) {
  $form_values = $form_state['values'];
  $tools = om_tools_get();
  $reset = 0;     
  //dsm($form_values);
  $om_tools = array();
  foreach ($form_values as $name => $value) {
    list($module) = explode('_', $name);
    if (in_array($module, $tools)) $om_tools[$module][$name] = $value;
    $om_tool_name = array_reverse(explode('_', $name));
    if ($om_tool_name[0] == 'reset') $reset += $value;    
  }
  //dsm($om_tools);
  if ($form_values['op'] == t('Initialize Settings')) { 
    drupal_set_message(t('Your settings has been initialized successfully.'));
  }
  elseif ($form_values['op'] == t('Save Settings')){
    drupal_set_message(t('Your settings has been saved.'));
  } 
  elseif ($form_values['op'] == t('Save Settings Again')){
    drupal_set_message(t('Your settings has been saved again.'));
  } 
  if ($reset) drupal_set_message(t('<strong>NOTE: When you reset any tool, hit "Save Settings Again".</strong>'));   
  
  // Save all settings in 1 variable
  variable_set('om_tools', $om_tools);
} 


/**
 * Admin Form - Advanced Editing
 *
 */
function om_tools_admin_advanced($form, &$form_state) {

  drupal_set_title(t('OM Tools 2 Advanced Editing'));
  
  $om_tools_values = variable_get('om_tools', '');
  //dsm($om_tools_values);

  // OM Tools backup container
  $om_tools_backup = variable_get('om_tools_backup', '');  
  
  $om_tools_array = '$om_tools = array(' . "\n"; 

  if (!empty($om_tools_values)) {    
    foreach ($om_tools_values as $tool => $tools_values) {
      // first level array key
      $om_tools_array .= "\t" . '\'' . $tool . '\' => array(' . "\n";
    
      foreach ($tools_values as $tool_var => $value) {
        // second leve key value pair
        if (!is_numeric($value)) $value = '\'' . $value . '\'';         
        $om_tools_array .= "\t\t" . '\'' . $tool_var . '\' => ' . $value . ',' . "\n";    
      }
      // each sub array closing
      $om_tools_array .= "\t" . '),' . "\n";   
    }
  }
  elseif(empty($om_tools_backup) && empty($om_tools_values)) {
    drupal_set_message(t('Your settings is empty, initialize your settings first'));    
  }
  elseif(!empty($om_tools_backup) && empty($om_tools_values)) {
    drupal_set_message(t('Your settings is empty, initialize your settings first or restore from backup'));    
  }  
  // var closing
  $om_tools_array .= ');';  
  
  $form = array();  
  $form['om_tools_admin_advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('OM Tools variable content'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
    '#description' => 'Edit all settings without the hassle of collapsing forms. Use this only if you really know what you\'re doing. You can always Backup/Restore your settings.',
  );
  $form['om_tools_admin_advanced']['admin_advanced'] = array(
    '#type' => 'textarea',
    '#title' => t(''),
    '#rows' => 30,
    '#default_value' => $om_tools_array,
  );  
   
  // button save will not show on empty values 
  if (!empty($om_tools_values)) $form['submit'] = array( '#type' => 'submit', '#value' => t('Save'), );  
  // buton backup will only show if backup empty and current values in not empty 
  if (empty($om_tools_backup) && !empty($om_tools_values)) $form['backup'] = array( '#type' => 'submit', '#value' => t('Backup'), ); 
  // button update backup will shown if both backup and current values are not empty
  if (!empty($om_tools_backup) && !empty($om_tools_values)) $form['backup_update'] = array( '#type' => 'submit', '#value' => t('Update Backup'), ); 
  // button restore will show if backup is not empty        
  if (!empty($om_tools_backup)) $form['restore'] = array( '#type' => 'submit', '#value' => t('Restore'), );  
  // button delete will show if both backup and current values are not empty  
  if (!empty($om_tools_backup) && !empty($om_tools_values)) $form['delete'] = array( '#type' => 'submit', '#value' => t('Delete'), );   
  
  return $form;
}

/**
 * Admin Advanced Submit
 * 
 */
function om_tools_admin_advanced_submit($form, $form_state) {
  
  $form_values = $form_state['values'];
  //dsm($form_values['om_tools_admin_advanced']['admin_advanced']);
  $om_tools = ''; 
  ob_start();
  eval($form_values['om_tools_admin_advanced']['admin_advanced']);
  ob_end_clean();
  //dsm($om_tools);
  // update data
  if ($form_values['op'] == t('Save')) { 
    variable_set('om_tools', $om_tools);
    drupal_set_message(t('All settings are saved.'));
  }
  elseif ($form_values['op'] == t('Backup')) {
    variable_set('om_tools_backup', $om_tools);
    drupal_set_message(t('Backup is successful.'));
  }
  elseif ($form_values['op'] == t('Update Backup')) {
    variable_set('om_tools_backup', $om_tools);
    drupal_set_message(t('Backup is updated successfully.'));
  }  
  elseif ($form_values['op'] == t('Restore')) {
    $om_tools = variable_get('om_tools_backup', '');
    if (!empty($om_tools)) {
      variable_set('om_tools', $om_tools);    
      drupal_set_message(t('All settings are restored from backup.'));
    }
    else {
      drupal_set_message(t('Backup file is empty.'));    
    }
  }
  elseif ($form_values['op'] == t('Delete')) {
    variable_set('om_tools', '');    
    drupal_set_message(t('All settings have been deleted.'));  
  }
}



